/******************************************************************************/
/*
 * eRIC Example I2C V1.1
 * Low Power Radio Solutions
 * March 2017
 * Built with CCS V7.3.0.00019
 * This example will Read or Write 24LC01B EEprom using I2C. 24LC01B is 128Bytes EEPROM. So the program uses Uart and commands
 * to read/write a location. The command is AT=xxyy. xx is address and yy is data. To read, it is AT=xx? , xx is address. So
 * for example to read location 10, its hex value is 0x0A so command will be AT=0A? , similarly to write location 10 a value of
 * 55 then command is AT=0A55.
 * Pin22 is SDA and PIn21 is SCL.
 *     |x      VCC|---Connected to eRIC VCC
 *     |x      WP |---Connected to eRIC GND
 *     |x 	   SCL|---Connected to eRIC pin21. Pin21 is connected to 10k Pull up.
 *  GND|Vss    SDA|---Connected to eRIC PIn22. Pin22 is connected to 10k pull up.
 *
 */

/******************************************************************************/
//Version V1.1
#include<cc430f5137.h>
#include "eRIC.h"
#include <stdio.h>
#include <string.h>

#define Address 0x0050  //THis is address for slave or own
#define Receiver

int main(void)
{
	eRIC_WDT_Stop();                   //Stop watch dog timer, just in case
	eRIC_GlobalInterruptDisable();     //Global interrupts disabled

	eROS_Initialise(0);       //Initialise eROS. CPU freq is 1048576 default
	//eRIC_SetCpuFrequency(32768);
	Pin22_FunctionI2CB_SDA(); //I2C Data
	Pin21_FunctionI2CB_SCl(); //I2C clock

#ifdef Receiver
	eRIC_I2CB_Initialise(100000,0,Address);// Initialise I2C with 100000Clock, Slave, and own address as 0x50
	Pin16_SetAsOutput();
	Pin17_SetAsOutput();
	Pin18_SetAsOutput();
	Pin19_SetAsOutput();
	eRIC_I2CB_AsReceiver();
	eRIC_I2CB_Start();//Start I2C
	char Temp = 0;
	while(1)
	{
	 Temp = 0;
	 Temp = eRIC_I2CB_ReceiveByte();// Return received byte which is the data at the address
	 if(Temp & 0x01)
		 Pin16_SetHigh();
	 else
		 Pin16_SetLow();
	 if(Temp & 0x02)
		 Pin17_SetHigh();
	 else
		 Pin17_SetLow();
	 if(Temp & 0x04)
		 Pin18_SetHigh();
	 else
		 Pin18_SetLow();
	 if(Temp & 0x08)
		 Pin19_SetHigh();
	 else
		 Pin19_SetLow();
	}


#else//Transmitter
	eRIC_I2CB_Initialise(100000,1,Address);// Initialise I2C with 100000Clock, master, and slave address as 0x50
	Pin16_SetAsInput();
	Pin16_PullDownEnable();
	Pin17_SetAsInput();
	Pin17_PullDownEnable();
	Pin18_SetAsInput();
	Pin18_PullDownEnable();
	Pin19_SetAsInput();
	Pin19_PullDownEnable();
	eRIC_I2CB_AsTransmitter();
   char Temp = 0;
	while(1)
	{
		Temp = 0;
		if(Pin16_Read())
		{
			Temp |=0x01;
		}
		if(Pin17_Read())
		{
			Temp |=0x02;
		}
		if(Pin18_Read())
		{
			Temp |=0x04;
	    }
		if(Pin19_Read())
		{
			Temp |=0x08;
		}
		eRIC_I2CB_Start();
		eRIC_I2CB_SendByte(Temp);//Send data to write at the address location
		while(eRIC_I2CB_TxBufferIsBusy());
		eRIC_I2CB_Stop();//Stop i2C
		while(eRIC_I2CB_IsBusBusy()); //wait while I2C is busy
	}

#endif

}












/*


#define SlaveAddress 0x0050  //THis is address for 24LC01B. It is 1010xxxR/w but eric I2C is right justified

char I2C_ReadAddress(char Address);
void I2C_WriteAddress(char Address, char Data);


int main(void)
{
	eRIC_WDT_Stop();                   //Stop watch dog timer, just in case
	eRIC_GlobalInterruptDisable();     //Global interrupts disabled

	eROS_Initialise(0);       //Initialise eROS. CPU freq is 1048576 default
	Pin22_FunctionI2CB_SDA(); //I2C Data
	Pin21_FunctionI2CB_SCl(); //I2C clock

	eRIC_I2CB_Initialise(100000,1,SlaveAddress);// Initialise I2C with 100000Clock, master, and slave address as 0x50 which when combined with tx or rx register it will be 0xA0 or 0xA1

	Pin3_FunctionUartATxOUT();          //Map pin3 as Uart TX Moved to here in V1.5.5
	Pin4_FunctionUartARxD();            //Map Pin4 as Uart Rx Moved to here in V1.5.5
	eRIC_UARTAInitialise(19200);

	eRIC_TimerA0_Setup(eRICTimer_Cs_32k+eRICTimer_Div_1+eRICTimer_UpMode+eRICTimer_Reset);
	eRIC_TimerA0_Capture0orCompare0_Data = 34; //34 clock cycles which will be 34*1000000/32768=1.041 ms for 20 bits at 19200
	eRIC_TimerA0_Capture0orCompare0Setup(eRICTimer_CompareMode+eRICTimer_CCInterruptDisable+eRICTimer_OutputMode_OutputOnly);

	unsigned char Rx_Uart_Data[8];
	volatile char i = 0 ;
	while(1)
	{
		i =0;
		while(eRIC_UartARxHasInterrupted())//If eRIC received data from Uart
		{
			if(i<7)
			{
				Rx_Uart_Data[i++] =  eRIC_UartAReceiveByte(); //Read all data it will AT=xxyy or AT=xx?
			}
			else
			{
				eRIC_UartAReceiveByte();//Anything else ignore data
			}
			eRIC_TimerA0_Reset();
			eRIC_TimerA0_Capture0orCompare0InterruptFlagClear();
			while(!eRIC_UartARxHasInterrupted())
			{
				if(eRIC_TimerA0_Capture0orCompare0HasInterrupted()) //Wait for Uart time out. It based on 20 bits at 19200 baud which is 1.04 ms
				{
					eRIC_TimerA0_Capture0orCompare0InterruptFlagClear();
					break;
				}
			}
		}
		if(i>5)
		{
			if(((Rx_Uart_Data[0] == 'A') && (Rx_Uart_Data[1] == 'T'))&& (Rx_Uart_Data[2] == '='))//If recevied Uart has AT=
			{
				i= 0;
				while(i<7)
				{
					while(eRIC_UartATxBufferIsBusy());
					eRIC_UartASendByte(Rx_Uart_Data[i]);
					if(Rx_Uart_Data[i++] == '?')
						break;
				}
				if(Rx_Uart_Data[5] == '?')
				{
					char Address =  eRIC_Ascii2Hex(Rx_Uart_Data[3]);
					Address <<=4;
					Address|= eRIC_Ascii2Hex(Rx_Uart_Data[4]);
					char data = I2C_ReadAddress(Address);
					while(eRIC_UartATxBufferIsBusy());
					eRIC_UartASendByte(eRIC_Int2Ascii(data>>4 &0x0F));
					while(eRIC_UartATxBufferIsBusy());
					eRIC_UartASendByte(eRIC_Int2Ascii(data & 0x0F));
				}
				else
				{
					char Address =  eRIC_Ascii2Hex(Rx_Uart_Data[3]);
					Address <<=4;
					Address|= eRIC_Ascii2Hex(Rx_Uart_Data[4]);
					char Data = eRIC_Ascii2Hex(Rx_Uart_Data[5]);
					Data <<=4;
					Data|= eRIC_Ascii2Hex(Rx_Uart_Data[6]);
					I2C_WriteAddress(Address,Data);
				}
			}
		}
	}
}


char I2C_ReadAddress(char Address)
{
	eRIC_I2CB_AsTransmitter(); //I2C set as Master TX
	eRIC_I2CB_Start();//Start I2C. this will send address
	eRIC_I2CB_SendByte(Address); //Send address byte to read data
	while(eRIC_I2CB_TxBufferIsBusy());
	eRIC_I2CB_AsReceiver(); //I2C set as receiver
	eRIC_I2CB_Start();//Start I2C
	while(eRIC_I2CB_IsStartActive()); //wait while start is active, it needs to be cleared
	eRIC_I2CB_Stop(); //Stop I2C
	return eRIC_I2CB_ReceiveByte();// Return recived byte which is the data at the address
}

void I2C_WriteAddress(char Address, char Data)
{
	eRIC_I2CB_AsTransmitter(); //Set I2C as Master Tx
	eRIC_I2CB_Start();//Start I2C, this will send slave address
	eRIC_I2CB_SendByte(Address);//Send address byte
	eRIC_I2CB_SendByte(Data);//Send data to write at the address location
	while(eRIC_I2CB_TxBufferIsBusy());
	eRIC_I2CB_Stop();//Stop i2C
	while(eRIC_I2CB_IsBusBusy()); //wait while I2C is busy
}
*/
//Added in V1.1
void eRIC_RfDataReceivedInterrupt()   //V1.1 Add code here to deal with  available received data..THis is triggered when interrupt is enabled and a packet is received
{

}
